package Domain

import (
	"os"
	"path/filepath"
	"time"
	"fmt"
	"strings"

	"github.com/Sirupsen/logrus"
)

var LogS *logrus.Logger
var day string
var logfile *os.File
// 当前项目根目录
var API_ROOT string

// 初始化Log日志记录
func init() {
	var err error
	LogS = logrus.New()
	LogS.Formatter = new(logrus.JSONFormatter)
	//log.Formatter = new(logrus.TextFormatter) // default
	LogS.Level = logrus.DebugLevel

	if !IsDirExists(GetPath() + "/Runtime") {
		if mkdirerr := MkdirFile(GetPath() + "/Runtime"); mkdirerr != nil {
			fmt.Println(mkdirerr)
		}
	}

	logfile, err = os.OpenFile(GetPath()+"/Runtime/"+time.Now().Format("2006-01-02")+".log", os.O_RDWR|os.O_APPEND, 0666)
	if err != nil {
		logfile, err = os.Create(GetPath() + "/Runtime/" + time.Now().Format("2006-01-02") + ".log")
		if err != nil {
			fmt.Println(err)
		}
	}
	LogS.Out = logfile
	day = time.Now().Format("02")

}

// 检测是否跨天了,把记录记录到新的文件目录中
func updateLogFile() {
	var err error
	day2 := time.Now().Format("02")
	if day2 != day {
		logfile.Close()
		logfile, err = os.Create(GetPath() + "/Runtime/" + time.Now().Format("2006-01-02") + ".log")
		if err != nil {
			fmt.Println(err)
		}
		LogS.Out = logfile
		day = day2
	}
}

// 记录Debug信息
func LogDebug(str ...interface{}) {
	if GetRunTime() == "dev" || GetRunTime() == "test" {
		updateLogFile()
		fmt.Println(str)
		LogS.Debug(str)
	}
}

// 记录Info信息
func LogInfo(str ...interface{}) {
	updateLogFile()
	LogS.Info(str)
}

// 记录Error信息
func LogError(str ...interface{}) {
	updateLogFile()
	fmt.Println(str)
	LogS.Error(str)
}


// 获取项目路径
func GetPath() string {
	if API_ROOT != "" {
		return API_ROOT
	}

	dir, err := filepath.Abs(filepath.Dir(os.Args[0]))
	if err != nil {
		print(err.Error())
	}

	API_ROOT = strings.Replace(dir, "\\", "/", -1)
	return API_ROOT
}

// 判断文件目录否存在
func IsDirExists(path string) bool {
	fi, err := os.Stat(path)

	if err != nil {
		return os.IsExist(err)
	} else {
		return fi.IsDir()
	}

}

// 创建文件
func MkdirFile(path string) error {
	err := os.Mkdir(path, os.ModePerm) //在当前目录下生成md目录
	if err != nil {
		return err
	}
	return nil
}

// 获取当前系统环境
func GetRunTime() string {
	//获取系统环境变量
	RUN_TIME := os.Getenv("RUN_TIME")
	if RUN_TIME == "" {
		panic("No RUN_TIME Can't start")
	}
	return RUN_TIME
}